# nnde

nnde is a package of Python modules which implement a set of neural networks which solve ordinary and partial differential equations using technique of (Lagaris et al. (1998))[10.1109/72.712178]

The package is described in [Winter and Weigel, 2021](https://github.com/elwinter/nnde_joss_paper).

Demos are available in the repository [nnde_demos](https://github.com/elwinter/nnde_demos).

# Contact

Eric Winter

eric.winter62@gmail.com
